# Dummy Task Template for Tagging

## 🌴 Dependencies

- torch
- pytorch-rex
- transformers

## 💾 Data Preprocessing

Make sure to clean the dataset first instead of cleaning every time.

## 🚀 QuickStart

1. add your transformation in `data.py`
2. change your model in `model.py`
3. Complete the task in `task.py`
4. run `bash run.sh` to start

## ✉️ Contact

If you found any problems or you have ideas to improve this project,
feel free to contact me via [GitHub](https://github.com/Spico197/REx) issues.
